@@ -1,4 +1,5 @@
 # encoding: utf-8
+require 'multi_json'
 require 'tempfile'
 
 Given /^I am in (.*)$/ do |example_dir_relative_path|
@@ -63,7 +64,9 @@ end
 
 Then /^it should (fail|pass)$/ do |success|
   if success == 'fail'
-    last_exit_status.should_not == 0
+    if last_exit_status == 0
+      raise "Passed when expected to fail\nSTDOUT:\n#{last_stdout}\nSTDERR:\n#{last_stderr}"
+    end
   else
     if last_exit_status != 0
       raise "Failed with exit status #{last_exit_status}\nSTDOUT:\n#{last_stdout}\nSTDERR:\n#{last_stderr}"
@@ -95,7 +98,7 @@ Then /^the output should be$/ do |text|
 end
 
 Then /^it should (fail|pass) with JSON$/ do |success, text|
-  JSON.parse(last_stdout).should == JSON.parse(text)
+  MultiJson.load(last_stdout).should == MultiJson.load(text)
   Then("it should #{success}")
 end
 
@@ -105,7 +108,7 @@ end
 
 Then /^"([^"]*)" with junit duration "([^"]*)" should contain$/ do |actual_file, duration_replacement, text|
   actual = IO.read(actual_file)
-  actual = replace_junit_duration(actual, duration_replacement) 
+  actual = replace_junit_duration(actual, duration_replacement)
   actual = strip_ruby186_extra_trace(actual)
   actual.should == text
 end
@@ -138,6 +141,10 @@ Then /^STDERR should be empty$/ do
   last_stderr.should == ""
 end
 
+Then /^STDERR should have warning message$/ do
+  last_stderr.should include("[warning]")
+end
+
 Then /^"([^"]*)" should exist$/ do |file|
   File.exists?(file).should be_true
   FileUtils.rm(file)
@@ -168,5 +175,5 @@ Then /^print output$/ do
 end
 
 Then /^the output should contain the following JSON:$/ do |json_string|
-  JSON.parse(last_stdout).should == JSON.parse(json_string)
+  MultiJson.load(last_stdout).should == MultiJson.load(json_string)
 end
