@@ -35,7 +35,7 @@ module Cucumber
 
       def accept(visitor)
         return if Cucumber.wants_to_quit
-        invoke(visitor.step_mother, visitor.configuration)
+        invoke(visitor.runtime, visitor.configuration)
         visit_step_result(visitor)
       end
 
@@ -52,13 +52,13 @@ module Cucumber
         )
       end
 
-      def invoke(step_mother, configuration)
-        find_step_match!(step_mother, configuration)
+      def invoke(runtime, configuration)
+        find_step_match!(runtime, configuration)
         unless @skip_invoke || configuration.dry_run? || @exception || @step_collection.exception
           @skip_invoke = true
           begin
             @step_match.invoke(@multiline_arg)
-            step_mother.after_step
+            runtime.after_step
             status!(:passed)
           rescue Pending => e
             failed(configuration, e, false)
@@ -77,10 +77,10 @@ module Cucumber
         end
       end
 
-      def find_step_match!(step_mother, configuration)
+      def find_step_match!(runtime, configuration)
         return if @step_match
         begin
-          @step_match = step_mother.step_match(@name)
+          @step_match = runtime.step_match(@name)
         rescue Undefined => e
           failed(configuration, e, true)
           status!(:undefined)
@@ -90,7 +90,7 @@ module Cucumber
           status!(:failed)
           @step_match = NoStepMatch.new(@step, @name)
         end
-        step_mother.step_visited(self)
+        runtime.step_visited(self)
       end
 
       def failed(configuration, e, clear_backtrace)
@@ -107,13 +107,16 @@ module Cucumber
 
       # This constant is appended to by Cuke4Duke. Do not change its name
       BACKTRACE_FILTER_PATTERNS = [/vendor\/rails|lib\/cucumber|bin\/cucumber:|lib\/rspec|gems\/|minitest|test\/unit/]
+      if(Cucumber::JRUBY)
+        BACKTRACE_FILTER_PATTERNS << /org\/jruby/
+      end
       PWD_PATTERN = /#{Regexp.escape(Dir.pwd)}\//m
 
       # This is to work around double ":in " segments in JRuby backtraces. JRuby bug?
       def filter_backtrace(e)
         return e if Cucumber.use_full_backtrace
         e.backtrace.each{|line| line.gsub!(PWD_PATTERN, "./")}
-        
+
         filtered = (e.backtrace || []).reject do |line|
           BACKTRACE_FILTER_PATTERNS.detect { |p| line =~ p }
         end
@@ -178,7 +181,7 @@ module Cucumber
       end
 
       def language
-        @step.language
+        @step.language || raise("Language is required on #{@step}")
       end
 
       def gherkin_statement
