@@ -5,7 +5,7 @@ require 'gherkin/formatter/escaping'
 module Cucumber
   module Ast
     # Step Definitions that match a plain text Step with a multiline argument table
-    # will receive it as an instance of Table. A Table object holds the data of a 
+    # will receive it as an instance of Table. A Table object holds the data of a
     # table parsed from a feature file and lets you access and manipulate the data
     # in different ways.
     #
@@ -26,13 +26,13 @@ module Cucumber
     class Table
       class Different < StandardError
         attr_reader :table
-        
+
         def initialize(table)
           super('Tables were not identical')
           @table = table
         end
       end
-      
+
       class Builder
         attr_reader :rows
 
@@ -50,7 +50,7 @@ module Cucumber
 
       include Enumerable
       include Gherkin::Rubify
-      
+
       NULL_CONVERSIONS = Hash.new({ :strict => false, :proc => lambda{ |cell_value| cell_value } }).freeze
 
       attr_accessor :file
@@ -76,7 +76,7 @@ module Cucumber
         @cell_class = Cell
         raw = ensure_array_of_array(rubify(raw))
         # Verify that it's square
-        transposed = raw.transpose
+        raw.transpose
         create_cell_matrix(raw)
         @conversion_procs = conversion_procs
         @header_mappings = header_mappings
@@ -108,7 +108,7 @@ module Cucumber
       def transpose
         self.class.new(raw.transpose, @conversion_procs.dup, @header_mappings.dup, @header_conversion_proc)
       end
-      
+
       # Converts this table into an Array of Hash where the keys of each
       # Hash are the headers in the table. For example, a Table built from
       # the following plain text:
@@ -126,7 +126,7 @@ module Cucumber
       def hashes
         @hashes ||= build_hashes
       end
-      
+
       # Converts this table into a Hash where the first column is
       # used as keys and the second column is used as values
       #
@@ -137,7 +137,7 @@ module Cucumber
       #
       #   {'a' => '2', 'b' => '3'}
       #
-      # The table must be exactly two columns wide 
+      # The table must be exactly two columns wide
       #
       def rows_hash
         return @rows_hash if @rows_hash
@@ -163,7 +163,7 @@ module Cucumber
         end
       end
 
-      def column_names	#:nodoc:
+      def column_names #:nodoc:
         @col_names ||= cell_matrix[0].map { |cell| cell.value }
       end
 
@@ -193,7 +193,7 @@ module Cucumber
       #  | x             | y             |
       #
       #  table.match(/table:column_1_name,column_2_name/) #=> non-nil
-      #  
+      #
       # Note: must use 'table:' prefix on match
       def match(pattern)
         header_to_match = "table:#{headers.join(',')}"
@@ -218,7 +218,7 @@ module Cucumber
       #   | 123456       | xyz     |
       #   | 345678       | abc     |
       #
-      # A StepDefinition receiving this table can then map the columns 
+      # A StepDefinition receiving this table can then map the columns
       # with both Regexp and String:
       #
       #   table.map_headers!(/phone( number)?/i => :phone, 'Address' => :address)
@@ -238,20 +238,20 @@ module Cucumber
       #   # => ['phone number', 'ADDRESS']
       #
       def map_headers!(mappings={}, &block)
+        Kernel.warn "[warning] map_headers! will be deprecated, please use map_headers instead."
+        clear_cache!
         @header_mappings = mappings
         @header_conversion_proc = block
       end
 
       # Returns a new Table where the headers are redefined. See #map_headers!
-      def map_headers(mappings={})
-        table = self.dup
-        table.map_headers!(mappings)
-        table
+      def map_headers(mappings={}, &block)
+        self.class.new raw.dup, @conversion_procs.dup, mappings, block
       end
 
       # Change how #hashes converts column values. The +column_name+ argument identifies the column
-      # and +conversion_proc+ performs the conversion for each cell in that column. If +strict+ is 
-      # true, an error will be raised if the column named +column_name+ is not found. If +strict+ 
+      # and +conversion_proc+ performs the conversion for each cell in that column. If +strict+ is
+      # true, an error will be raised if the column named +column_name+ is not found. If +strict+
       # is false, no error will be raised. Example:
       #
       #   Given /^an expense report for (.*) with the following posts:$/ do |table|
@@ -262,6 +262,7 @@ module Cucumber
       #   end
       #
       def map_column!(column_name, strict=true, &conversion_proc)
+        Kernel.warn "[warning] map_column! will be deprecated"
         @conversion_procs[column_name.to_s] = { :strict => strict, :proc => conversion_proc }
         self
       end
@@ -269,7 +270,7 @@ module Cucumber
       # Compares +other_table+ to self. If +other_table+ contains columns
       # and/or rows that are not in self, new columns/rows are added at the
       # relevant positions, marking the cells in those rows/columns as
-      # <tt>surplus</tt>. Likewise, if +other_table+ lacks columns and/or 
+      # <tt>surplus</tt>. Likewise, if +other_table+ lacks columns and/or
       # rows that are present in self, these are marked as <tt>missing</tt>.
       #
       # <tt>surplus</tt> and <tt>missing</tt> cells are recognised by formatters
@@ -300,9 +301,10 @@ module Cucumber
       # an Array of Hash (similar to the structure returned by #hashes).
       #
       # Calling this method is particularly useful in <tt>Then</tt> steps that take
-      # a Table argument, if you want to compare that table to some actual values. 
+      # a Table argument, if you want to compare that table to some actual values.
       #
       def diff!(other_table, options={})
+        Kernel.warn "[warning] diff! will be deprecated"
         options = {
           :missing_row   => true,
           :surplus_row   => true,
@@ -315,7 +317,7 @@ module Cucumber
         other_table.convert_headers!
         other_table.convert_columns!
         ensure_green!
-                
+
         convert_headers!
         convert_columns!
 
@@ -339,7 +341,7 @@ module Cucumber
         last_change = nil
         missing_row_pos = nil
         insert_row_pos  = nil
-        
+
         changes.each do |change|
           if(change.action == '-')
             missing_row_pos = change.position + inserted
@@ -368,9 +370,9 @@ module Cucumber
             end
           end
         end
-        
+
         clear_cache!
-        should_raise = 
+        should_raise =
           missing_row_pos && options[:missing_row] ||
           insert_row_pos  && options[:surplus_row] ||
           missing_col     && options[:missing_col] ||
@@ -396,7 +398,7 @@ module Cucumber
       def verify_column(column_name) #:nodoc:
         raise %{The column named "#{column_name}" does not exist} unless raw[0].include?(column_name)
       end
-      
+
       def verify_table_width(width) #:nodoc:
         raise %{The table must have exactly #{width} columns} unless raw[0].size == width
       end
@@ -429,7 +431,7 @@ module Cucumber
       def headers #:nodoc:
         raw.first
       end
-      
+
       def header_cell(col) #:nodoc:
         cells_rows[0][col]
       end
@@ -452,7 +454,7 @@ module Cucumber
         formatter = Formatter::Pretty.new(nil, io, options)
         formatter.instance_variable_set('@indent', options[:indent])
         TreeWalker.new(nil, [formatter]).visit_multiline_arg(self)
-        
+
         Cucumber::Term::ANSIColor.coloring = c
         io.rewind
         s = "\n" + io.read + (" " * (options[:indent] - 2))
@@ -498,7 +500,7 @@ module Cucumber
         @conversion_procs.each do |column_name, conversion_proc|
           verify_column(column_name) if conversion_proc[:strict]
         end
-        
+
         cell_matrix.transpose.each do |col|
           column_name = col[0].value
           conversion_proc = @conversion_procs[column_name][:proc]
@@ -537,7 +539,7 @@ module Cucumber
       end
 
       def clear_cache! #:nodoc:
-        @hashes = @rows_hash = @rows = @columns = nil
+        @hashes = @rows_hash = @col_names = @rows = @columns = nil
       end
 
       def columns #:nodoc:
@@ -580,7 +582,7 @@ module Cucumber
         end
 
         unmapped_cols.each_with_index do |col, col_index|
-          empty_col = (0...cell_matrix.length).map do |row| 
+          empty_col = (0...cell_matrix.length).map do |row|
             SurplusCell.new(nil, self, -1)
           end
           cols << empty_col
@@ -600,7 +602,7 @@ module Cucumber
       end
 
       def hashes_to_array(hashes) #:nodoc:
-        header = hashes[0].keys
+        header = hashes[0].keys.sort
         [header] + hashes.map{|hash| header.map{|key| hash[key]}}
       end
 
@@ -698,12 +700,20 @@ module Cucumber
           SurplusCell === o || value == o.value
         end
 
+        def eql?(o)
+          self == o
+        end
+
+        def hash
+          0
+        end
+
         # For testing only
         def to_sexp #:nodoc:
           [:cell, @value]
         end
       end
-      
+
       class SurplusCell < Cell #:nodoc:
         def status
           :comment
@@ -712,6 +722,10 @@ module Cucumber
         def ==(o)
           true
         end
+
+        def hash
+          0
+        end
       end
     end
   end
