@@ -3,10 +3,17 @@ module Cucumber
     # Walks the AST, executing steps and notifying listeners
     class TreeWalker
       attr_accessor :configuration #:nodoc:
-      attr_reader   :step_mother #:nodoc:
+      attr_reader   :runtime #:nodoc:
 
-      def initialize(step_mother, listeners = [], configuration = Cucumber::Configuration.default)
-        @step_mother, @listeners, @configuration = step_mother, listeners, configuration
+      def initialize(runtime, listeners = [], configuration = Cucumber::Configuration.default)
+        @runtime, @listeners, @configuration = runtime, listeners, configuration
+      end
+
+      def execute(scenario, skip_hooks)
+        runtime.with_hooks(scenario, skip_hooks) do
+          scenario.skip_invoke! if scenario.failed?
+          visit_steps(scenario.steps)
+        end
       end
 
       def visit_features(features)
@@ -152,9 +159,9 @@ module Cucumber
       def embed(file, mime_type, label)
         broadcast(file, mime_type, label)
       end
-      
+
       private
-      
+
       def broadcast(*args, &block)
         message = extract_method_name_from(caller)
         message.gsub!('visit_', '')
@@ -165,8 +172,9 @@ module Cucumber
         else
           send_to_all(message, *args)
         end
+        self
       end
-      
+
       def send_to_all(message, *args)
         @listeners.each do |listener|
           if listener.respond_to?(message)
@@ -177,7 +185,7 @@ module Cucumber
       def extract_method_name_from(call_stack)
         call_stack[0].match(/in `(.*)'/).captures[0]
       end
-      
+
     end
   end
-end
\ No newline at end of file
+end
