@@ -68,8 +68,12 @@ module Cucumber
         @options[:dotcucumber]
       end
 
-      def build_tree_walker(step_mother)
-        Ast::TreeWalker.new(step_mother, formatters(step_mother), self)
+      def snippet_type
+        @options[:snippet_type] || :regexp
+      end
+
+      def build_tree_walker(runtime)
+        Ast::TreeWalker.new(runtime, formatters(runtime), self)
       end
 
       def formatter_class(format)
@@ -106,7 +110,7 @@ module Cucumber
       end
 
       def feature_files
-        potential_feature_files = paths.map do |path|
+        potential_feature_files = with_default_features_path(paths).map do |path|
           path = path.gsub(/\\/, '/') # In case we're on windows. Globs don't work with backslashes.
           path = path.chomp('/')
           if File.directory?(path)
@@ -123,7 +127,9 @@ module Cucumber
       end
 
       def feature_dirs
-        paths.map { |f| File.directory?(f) ? f : File.dirname(f) }.uniq
+        dirs = paths.map { |f| File.directory?(f) ? f : File.dirname(f) }.uniq
+        dirs.delete('.') unless paths.include?('.')
+        with_default_features_path(dirs)
       end
 
       def log
@@ -133,35 +139,40 @@ module Cucumber
         logger.level = Logger::DEBUG if self.verbose?
         logger
       end
-      
+
       def tag_expression
         Gherkin::TagExpression.new(@options[:tag_expressions])
       end
-      
+
       def filters
         @options.filters
       end
-      
+
       def formats
         @options[:formats]
       end
-      
+
       def options
         warn("Deprecated: Configuration#options will be removed from the next release of Cucumber. Please use the configuration object directly instead.")
         @options
       end
-      
+
       def paths
-        @options[:paths].empty? ? ['features'] : @options[:paths]
+        @options[:paths]
       end
     private
+      def with_default_features_path(paths)
+        return ['features'] if paths.empty?
+        paths
+      end
 
-      def formatters(step_mother)
+
+      def formatters(runtime)
         # TODO: We should remove the autoformat functionality. That
         # can be done with the gherkin CLI.
         if @options[:autoformat]
           require 'cucumber/formatter/pretty'
-          return [Formatter::Pretty.new(step_mother, nil, @options)]
+          return [Formatter::Pretty.new(runtime, nil, @options)]
         end
 
         @options[:formats].map do |format_and_out|
@@ -169,7 +180,7 @@ module Cucumber
           path_or_io = format_and_out[1]
           begin
             formatter_class = formatter_class(format)
-            formatter_class.new(step_mother, path_or_io, @options)
+            formatter_class.new(runtime, path_or_io, @options)
           rescue Exception => e
             e.message << "\nError creating formatter: #{format}"
             raise e
@@ -193,6 +204,7 @@ module Cucumber
       def arrange_formats
         @options[:formats] << ['pretty', @out_stream] if @options[:formats].empty?
         @options[:formats] = @options[:formats].sort_by{|f| f[1] == @out_stream ? -1 : 1}
+        @options[:formats].uniq!
         streams = @options[:formats].map { |(_, stream)| stream }
         if streams != streams.uniq
           raise "All but one formatter must use --out, only one can print to each stream (or STDOUT)"
