@@ -21,18 +21,22 @@ module Cucumber
         end
       end
 
-      def initialize(args, out_stream = STDOUT, error_stream = STDERR)
-        @args         = args
-        @out_stream   = out_stream
-
-        @error_stream = error_stream
+      def initialize(args, stdin=STDIN, out=STDOUT, err=STDERR, kernel=Kernel)
+        raise "args can't be nil" unless args
+        raise "out can't be nil" unless out
+        raise "err can't be nil" unless err
+        raise "kernel can't be nil" unless kernel
+        @args   = args
+        @out    = out
+        @err    = err
+        @kernel = kernel
         @configuration = nil
       end
 
       def execute!(existing_runtime = nil)
         trap_interrupt
         return @drb_output if run_drb_client
-        
+
         runtime = if existing_runtime
           existing_runtime.configure(configuration)
           existing_runtime
@@ -42,29 +46,39 @@ module Cucumber
 
         runtime.run!
         runtime.write_stepdefs_json
-        runtime.results.failure?
+        failure = runtime.results.failure? || Cucumber.wants_to_quit
+        @kernel.exit(failure ? 1 : 0)
       rescue ProfilesNotDefinedError, YmlLoadError, ProfileNotFound => e
-        @error_stream.puts e.message
-        true
+        @err.puts(e.message)
+      rescue SystemExit => e
+        @kernel.exit(e.status)
+      rescue Errno::EACCES, Errno::ENOENT => e
+        @err.puts("#{e.message} (#{e.class})")
+        @kernel.exit(1)
+      rescue Exception => e
+        @err.puts("#{e.message} (#{e.class})")
+        @err.puts(e.backtrace.join("\n"))
+        @kernel.exit(1)
       end
 
       def configuration
         return @configuration if @configuration
 
-        @configuration = Configuration.new(@out_stream, @error_stream)
+        @configuration = Configuration.new(@out, @err)
         @configuration.parse!(@args)
         Cucumber.logger = @configuration.log
         @configuration
       end
 
       private
-      
+
       def run_drb_client
         return false unless configuration.drb?
-        @drb_output = DRbClient.run(@args, @error_stream, @out_stream, configuration.drb_port)
+        warn("Spork is no longer supported as of Cucumber 1.3.0. Please downgrade to version 1.2.5")
+        @drb_output = DRbClient.run(@args, @err, @out, configuration.drb_port)
         true
       rescue DRbClientError => e
-        @error_stream.puts "WARNING: #{e.message} Running features locally:"
+        @err.puts "WARNING: #{e.message} Running features locally:"
       end
 
       def trap_interrupt
