@@ -1,3 +1,4 @@
+require 'cucumber/platform'
 module Cucumber
   module Constantize #:nodoc:
     def constantize(camel_cased_word)
@@ -9,7 +10,7 @@ module Cucumber
 
         constant = ::Object
         names.each do |name|
-          constant = constant.const_defined?(name) ? constant.const_get(name) : constant.const_missing(name)
+          constant = constantize_name(constant, name)
         end
         constant
       rescue NameError => e
@@ -30,5 +31,14 @@ module Cucumber
         tr("-", "_").
         downcase
     end
+
+    private
+      def constantize_name(constant, name)
+        if Cucumber::RUBY_1_8_7
+          constant.const_defined?(name) ? constant.const_get(name) : constant.const_missing(name)
+        else
+          constant.const_defined?(name, false) ? constant.const_get(name, false) : constant.const_missing(name)
+        end
+      end
   end
-end
\ No newline at end of file
+end
