@@ -1,8 +1,9 @@
 # Proc extension to get more location info out of a proc
+require 'cucumber/platform'
 class Proc #:nodoc:
   PROC_PATTERN = /[\d\w]+@(.+):(\d+).*>/
   PWD = Dir.pwd
-  
+
   def to_comment_line
     "# #{file_colon_line}"
   end
@@ -16,6 +17,7 @@ class Proc #:nodoc:
       path, line = *to_s.match(PROC_PATTERN)[1..2]
       path = File.expand_path(path)
       pwd = File.expand_path(PWD)
+      pwd.force_encoding(path.encoding) unless Cucumber::RUBY_1_8_7
       if path.index(pwd)
         path = path[pwd.length+1..-1]
       elsif path =~ /.*\/gems\/(.*\.rb)$/
@@ -26,9 +28,9 @@ class Proc #:nodoc:
   else
     # This Ruby implementation doesn't implement Proc#to_s correctly
     STDERR.puts "*** THIS RUBY IMPLEMENTATION DOESN'T REPORT FILE AND LINE FOR PROCS ***"
-    
+
     def file_colon_line
       "UNKNOWN:-1"
     end
   end
-end 
+end
