@@ -4,15 +4,32 @@ require 'cucumber/formatter/summary'
 
 module Cucumber
   module Formatter
-    # This module contains helper methods that are used by formatters
-    # that print output to the terminal.
+
+    # This module contains helper methods that are used by formatters that
+    # print output to the terminal.
+    #
+    # FORMAT is a hash of Proc objects, keyed by step-definition types, e.g.
+    # "FORMAT[:passed]".  The Proc is called for each line of the step's
+    # output.
+    #
+    # format_step calls format_string, format_string calls format_for to obtain
+    # the formatting Proc.
+    #
+    # Example:
+    #
+    # The ANSI color console formatter defines a map of step-type to output
+    # color (e.g. "passed" to "green"), then builds methods named for the
+    # step-types (e.g. "def passed"), which themselves wrap the corresponding
+    # color-named methods provided by Term::ANSIColor (e.g. "def red").
+    #
+    # During output, each line is processed by passing it to the formatter Proc
+    # which returns the formatted (e.g. colored) string.
+
     module Console
       extend ANSIColor
       include Duration
       include Summary
 
-      FORMATS = Hash.new{|hash, format| hash[format] = method(format).to_proc}
-
       def format_step(keyword, step_match, status, source_indent)
         comment = if source_indent
           c = (' # ' + step_match.file_colon_line).indent(source_indent)
@@ -38,7 +55,7 @@ module Cucumber
       end
 
       def print_steps(status)
-        print_elements(step_mother.steps(status), status, 'steps')
+        print_elements(runtime.steps(status), status, 'steps')
       end
 
       def print_elements(elements, status, kind)
@@ -60,10 +77,10 @@ module Cucumber
       end
 
       def print_stats(features, options)
-        @failures = step_mother.scenarios(:failed).select { |s| s.is_a?(Cucumber::Ast::Scenario) || s.is_a?(Cucumber::Ast::OutlineTable::ExampleRow) }
+        @failures = runtime.scenarios(:failed).select { |s| s.is_a?(Cucumber::Ast::Scenario) || s.is_a?(Cucumber::Ast::OutlineTable::ExampleRow) }
         @failures.collect! { |s| (s.is_a?(Cucumber::Ast::OutlineTable::ExampleRow)) ? s.scenario_outline : s }
 
-        if !@failures.empty?          
+        if !@failures.empty?
           @io.puts format_string("Failing Scenarios:", :failed)
           @failures.each do |failure|
             profiles_string = options.custom_profiles.empty? ? '' : (options.custom_profiles.map{|profile| "-p #{profile}" }).join(' ') + ' '
@@ -73,8 +90,8 @@ module Cucumber
           @io.puts
         end
 
-        @io.puts scenario_summary(step_mother) {|status_count, status| format_string(status_count, status)}
-        @io.puts step_summary(step_mother) {|status_count, status| format_string(status_count, status)}
+        @io.puts scenario_summary(runtime) {|status_count, status| format_string(status_count, status)}
+        @io.puts step_summary(runtime) {|status_count, status| format_string(status_count, status)}
 
         @io.puts(format_duration(features.duration)) if features && features.duration
 
@@ -90,22 +107,22 @@ module Cucumber
         string = "#{message}\n#{e.backtrace.join("\n")}".indent(indent)
         @io.puts(format_string(string, status))
       end
-      
-      # http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-talk/10655 
+
+      # http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-talk/10655
       def linebreaks(s, max)
         s.gsub(/.{1,#{max}}(?:\s|\Z)/){($& + 5.chr).gsub(/\n\005/,"\n").gsub(/\005/,"\n")}.rstrip
       end
 
       def print_snippets(options)
         return unless options[:snippets]
-        undefined = step_mother.steps(:undefined)
+        undefined = runtime.steps(:undefined)
         return if undefined.empty?
-        
-        unknown_programming_language = step_mother.unknown_programming_language?
+
+        unknown_programming_language = runtime.unknown_programming_language?
         snippets = undefined.map do |step|
           step_name = Undefined === step.exception ? step.exception.step_name : step.name
           step_multiline_class = step.multiline_arg ? step.multiline_arg.class : nil
-          snippet = @step_mother.snippet_text(step.actual_keyword, step_name, step_multiline_class)
+          snippet = @runtime.snippet_text(step.actual_keyword, step_name, step_multiline_class)
           snippet
         end.compact.uniq
 
@@ -114,9 +131,9 @@ module Cucumber
         @io.puts format_string(text, :undefined)
 
         if unknown_programming_language
-          @io.puts format_string("\nIf you want snippets in a different programming language,\n" +
-                  "just make sure a file with the appropriate file extension\n" +
-                  "exists where cucumber looks for step definitions.", :failed)
+          @io.puts format_string("\nIf you want snippets in a different programming language," +
+                                 "\njust make sure a file with the appropriate file extension" +
+                                 "\nexists where cucumber looks for step definitions.", :failed)
         end
 
         @io.puts
@@ -125,7 +142,7 @@ module Cucumber
 
       def print_passing_wip(options)
         return unless options[:wip]
-        passed = step_mother.scenarios(:passed)
+        passed = runtime.scenarios(:passed)
         if passed.any?
           @io.puts format_string("\nThe --wip switch was used, so I didn't expect anything to pass. These scenarios passed:", :failed)
           print_elements(passed, :passed, "scenarios")
@@ -175,14 +192,27 @@ module Cucumber
         @delayed_messages = []
       end
 
+      def print_profile_information
+        return if @options[:skip_profile_information] || @options[:profiles].nil? || @options[:profiles].empty?
+        profiles = @options[:profiles]
+        profiles_sentence = ''
+        profiles_sentence = profiles.size == 1 ? profiles.first :
+          "#{profiles[0...-1].join(', ')} and #{profiles.last}"
+
+        @io.puts "Using the #{profiles_sentence} profile#{'s' if profiles.size> 1}..."
+      end
+
     private
 
-      def format_for(*keys)
-        key = keys.join('_').to_sym
-        fmt = FORMATS[key]
-        raise "No format for #{key.inspect}: #{FORMATS.inspect}" if fmt.nil?
-        fmt
-      end
+    FORMATS = Hash.new{ |hash, format| hash[format] = method(format).to_proc }
+
+    def format_for(*keys)
+      key = keys.join('_').to_sym
+      fmt = FORMATS[key]
+      raise "No format for #{key.inspect}: #{FORMATS.inspect}" if fmt.nil?
+      fmt
+    end
+
     end
   end
 end
