@@ -6,9 +6,9 @@ module Cucumber
     # Adapts Cucumber formatter events to Gherkin formatter events
     # This class will disappear when Cucumber is based on Gherkin's model.
     class GherkinFormatterAdapter
-      def initialize(gherkin_formatter, print_emtpy_match)
+      def initialize(gherkin_formatter, print_empty_match)
         @gf = gherkin_formatter
-        @print_emtpy_match = print_emtpy_match
+        @print_empty_match = print_empty_match
       end
 
       def before_feature(feature)
@@ -36,7 +36,7 @@ module Cucumber
 
       def before_step(step)
         @gf.step(step.gherkin_statement)
-        if @print_emtpy_match
+        if @print_empty_match
           if(@outline)
             match = Gherkin::Formatter::Model::Match.new(step.gherkin_statement.outline_args, nil)
           else
@@ -44,13 +44,14 @@ module Cucumber
           end
           @gf.match(match)
         end
+        @step_time = Time.now
       end
 
       def before_step_result(keyword, step_match, multiline_arg, status, exception, source_indent, background, file_colon_line)
         arguments = step_match.step_arguments.map{|a| Gherkin::Formatter::Argument.new(a.offset, a.val)}
         location = step_match.file_colon_line
         match = Gherkin::Formatter::Model::Match.new(arguments, location)
-        if @print_emtpy_match
+        if @print_empty_match
           # Trick the formatter to believe that's what was printed previously so we get arg highlights on #result
           @gf.instance_variable_set('@match', match)
         else
@@ -67,6 +68,12 @@ module Cucumber
         @gf.examples(examples.gherkin_statement)
       end
 
+      #used for capturing duration
+      def after_step(step)
+        step_finish = (Time.now - @step_time)
+        @gf.append_duration(step_finish)
+      end
+
       def after_feature(feature)
         @gf.eof
       end
@@ -76,7 +83,7 @@ module Cucumber
       end
 
       def embed(file, mime_type, label)
-        data = File.read(file)
+        data = File.open(file, 'rb') { |f| f.read }
         if defined?(JRUBY_VERSION)
           data = data.to_java_bytes
         end
