@@ -10,9 +10,9 @@ module Cucumber
       include Duration
       include Io
 
-      def initialize(step_mother, path_or_io, options)
+      def initialize(runtime, path_or_io, options)
         @io = ensure_io(path_or_io, "html")
-        @step_mother = step_mother
+        @runtime = runtime
         @options = options
         @buffer = {}
         @builder = create_builder(@io)
@@ -22,6 +22,7 @@ module Cucumber
         @header_red = nil
         @delayed_messages = []
         @img_id = 0
+        @inside_outline = false
       end
 
       def embed(src, mime_type, label)
@@ -42,20 +43,20 @@ module Cucumber
 
 
       def before_features(features)
-        @step_count = get_step_count(features)
+        @step_count = features.step_count
 
         # <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
         @builder.declare!(
           :DOCTYPE,
-          :html, 
-          :PUBLIC, 
+          :html,
+          :PUBLIC,
           '-//W3C//DTD XHTML 1.0 Strict//EN',
           'http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd'
         )
 
         @builder << '<html xmlns ="http://www.w3.org/1999/xhtml">'
           @builder.head do
-          @builder.meta(:content => 'text/html;charset=utf-8')
+          @builder.meta('http-equiv' => 'Content-Type', :content => 'text/html;charset=utf-8')
           @builder.title 'Cucumber'
           inline_css
           inline_js
@@ -93,7 +94,7 @@ module Cucumber
       def after_feature(feature)
         @builder << '</div>'
       end
-  
+
       def before_comment(comment)
         @builder << '<pre class="comment">'
       end
@@ -101,22 +102,22 @@ module Cucumber
       def after_comment(comment)
         @builder << '</pre>'
       end
-  
+
       def comment_line(comment_line)
         @builder.text!(comment_line)
         @builder.br
       end
-  
+
       def after_tags(tags)
         @tag_spacer = nil
       end
-  
+
       def tag_name(tag_name)
         @builder.text!(@tag_spacer) if @tag_spacer
         @tag_spacer = ' '
         @builder.span(tag_name, :class => 'tag')
       end
-  
+
       def feature_name(keyword, name)
         lines = name.split(/\r?\n/)
         return if lines.empty?
@@ -130,17 +131,17 @@ module Cucumber
           end
         end
       end
-  
+
       def before_background(background)
         @in_background = true
         @builder << '<div class="background">'
       end
-  
+
       def after_background(background)
         @in_background = nil
         @builder << '</div>'
       end
-  
+
       def background_name(keyword, name, file_colon_line, source_indent)
         @listing_background = true
         @builder.h3(:id => "background_#{@scenario_number}") do |h3|
@@ -156,7 +157,7 @@ module Cucumber
         css_class = {
           Ast::Scenario        => 'scenario',
           Ast::ScenarioOutline => 'scenario outline'
-        }[feature_element.class]      
+        }[feature_element.class]
         @builder << "<div class='#{css_class}'>"
       end
 
@@ -176,21 +177,23 @@ module Cucumber
           @builder.span(name, :class => 'val')
         end
       end
-  
+
       def before_outline_table(outline_table)
+        @inside_outline = true
         @outline_row = 0
         @builder << '<table>'
       end
-  
+
       def after_outline_table(outline_table)
         @builder << '</table>'
         @outline_row = nil
+        @inside_outline = false
       end
-      
+
       def before_examples(examples)
          @builder << '<div class="examples">'
       end
-      
+
       def after_examples(examples)
         @builder << '</div>'
       end
@@ -202,11 +205,11 @@ module Cucumber
           @builder.span(name, :class => 'val')
         end
       end
-  
+
       def before_steps(steps)
         @builder << '<ol>'
       end
-  
+
       def after_steps(steps)
         @builder << '</ol>'
       end
@@ -237,17 +240,18 @@ module Cucumber
         end
         @status = status
         return if @hide_this_step
-        set_scenario_color(status)      
-        @builder << "<li id='#{@step_id}' class='step #{status}'>"            
+        set_scenario_color(status)
+        @builder << "<li id='#{@step_id}' class='step #{status}'>"
       end
 
       def after_step_result(keyword, step_match, multiline_arg, status, exception, source_indent, background, file_colon_line)
         return if @hide_this_step
         # print snippet for undefined steps
         if status == :undefined
+          keyword = @step.actual_keyword if @step.respond_to?(:actual_keyword)
           step_multiline_class = @step.multiline_arg ? @step.multiline_arg.class : nil
           @builder.pre do |pre|
-            pre << @step_mother.snippet_text(@step.actual_keyword,step_match.instance_variable_get("@name") || '',step_multiline_class)
+            pre << @runtime.snippet_text(keyword,step_match.instance_variable_get("@name") || '',step_multiline_class)
           end
         end
         @builder << '</li>'
@@ -255,10 +259,8 @@ module Cucumber
       end
 
       def step_name(keyword, step_match, status, source_indent, background, file_colon_line)
-        @step_matches ||= []
         background_in_scenario = background && !@listing_background
-        @skip_step = @step_matches.index(step_match) || background_in_scenario
-        @step_matches << step_match
+        @skip_step = background_in_scenario
 
         unless @skip_step
           build_step(keyword, step_match, status)
@@ -266,6 +268,7 @@ module Cucumber
       end
 
       def exception(exception, status)
+        return if @hide_this_step
         build_exception_detail(exception)
       end
 
@@ -280,7 +283,7 @@ module Cucumber
           @builder << '<table>'
         end
       end
-  
+
       def after_multiline_arg(multiline_arg)
         return if @hide_this_step || @skip_step
         if Ast::Table === multiline_arg
@@ -294,15 +297,15 @@ module Cucumber
           @builder << h(string).gsub("\n", '&#x000A;')
         end
       end
-  
-  
+
+
       def before_table_row(table_row)
         @row_id = table_row.dom_id
         @col_index = 0
         return if @hide_this_step
         @builder << "<tr class='step' id='#{@row_id}'>"
       end
-  
+
       def after_table_row(table_row)
         return if @hide_this_step
         print_table_row_messages
@@ -315,7 +318,11 @@ module Cucumber
               end
             end
           end
-          set_scenario_color_failed
+          if table_row.exception.is_a? ::Cucumber::Pending
+            set_scenario_color_pending
+          else
+            set_scenario_color_failed
+          end
         end
         if @outline_row
           @outline_row += 1
@@ -326,12 +333,12 @@ module Cucumber
 
       def table_cell_value(value, status)
         return if @hide_this_step
-        
+
         @cell_type = @outline_row == 0 ? :th : :td
         attributes = {:id => "#{@row_id}_#{@col_index}", :class => 'step'}
         attributes[:class] += " #{status}" if status
         build_cell(@cell_type, value, attributes)
-        set_scenario_color(status)
+        set_scenario_color(status) if @inside_outline
         @col_index += 1
       end
 
@@ -339,10 +346,10 @@ module Cucumber
         @delayed_messages << message
         #@builder.pre(message, :class => 'message')
       end
-      
+
       def print_messages
         return if @delayed_messages.empty?
-        
+
         #@builder.ol do
           @delayed_messages.each do |ann|
             @builder.li(:class => 'step message') do
@@ -352,16 +359,16 @@ module Cucumber
         #end
         empty_messages
       end
-      
+
       def print_table_row_messages
         return if @delayed_messages.empty?
-        
+
         @builder.td(:class => 'message') do
           @builder << @delayed_messages.join(", ")
         end
         empty_messages
       end
-      
+
       def empty_messages
         @delayed_messages = []
       end
@@ -383,7 +390,7 @@ module Cucumber
             message = "#{message} (#{exception.class})"
           end
 
-          @builder.pre do 
+          @builder.pre do
             @builder.text!(message)
           end
         end
@@ -399,67 +406,30 @@ module Cucumber
       end
 
       def set_scenario_color(status)
-        if status == :undefined or status == :pending
+        if status.nil? or status == :undefined or status == :pending
           set_scenario_color_pending
         end
         if status == :failed
           set_scenario_color_failed
         end
       end
-      
+
       def set_scenario_color_failed
         @builder.script do
           @builder.text!("makeRed('cucumber-header');") unless @header_red
           @header_red = true
-          @builder.text!("makeRed('scenario_#{@scenario_number}');") unless @scenario_red
+          scenario_or_background = @in_background ? "background" : "scenario"
+          @builder.text!("makeRed('#{scenario_or_background}_#{@scenario_number}');") unless @scenario_red
           @scenario_red = true
         end
       end
-      
+
       def set_scenario_color_pending
         @builder.script do
           @builder.text!("makeYellow('cucumber-header');") unless @header_red
-          @builder.text!("makeYellow('scenario_#{@scenario_number}');") unless @scenario_red
-        end         
-      end
-
-      def get_step_count(features)
-        count = 0
-        features = features.instance_variable_get("@features")
-        features.each do |feature|
-          #get background steps
-          if feature.instance_variable_get("@background")
-            background = feature.instance_variable_get("@background")
-            background.init
-            background_steps = background.instance_variable_get("@steps").instance_variable_get("@steps")
-            count += background_steps.size
-          end
-          #get scenarios
-          feature.instance_variable_get("@feature_elements").each do |scenario|
-            scenario.init
-            #get steps
-            steps = scenario.instance_variable_get("@steps").instance_variable_get("@steps")
-            count += steps.size
-
-            #get example table
-            examples = scenario.instance_variable_get("@examples_array")
-            unless examples.nil?
-              examples.each do |example|
-                example_matrix = example.instance_variable_get("@outline_table").instance_variable_get("@cell_matrix")
-                count += example_matrix.size
-              end
-            end
-
-            #get multiline step tables
-            steps.each do |step|
-              multi_arg = step.instance_variable_get("@multiline_arg")
-              next if multi_arg.nil?
-              matrix = multi_arg.instance_variable_get("@cell_matrix")
-              count += matrix.size unless matrix.nil?
-            end
-          end
+          scenario_or_background = @in_background ? "background" : "scenario"
+          @builder.text!("makeYellow('#{scenario_or_background}_#{@scenario_number}');") unless @scenario_red
         end
-        return count
       end
 
       def build_step(keyword, step_match, status)
@@ -468,16 +438,16 @@ module Cucumber
           @builder.span(keyword, :class => 'keyword')
           @builder.span(:class => 'step val') do |name|
             name << h(step_name).gsub(/&lt;span class=&quot;(.*?)&quot;&gt;/, '<span class="\1">').gsub(/&lt;\/span&gt;/, '</span>')
-          end            
+          end
         end
-        
+
         step_file = step_match.file_colon_line
         step_file.gsub(/^([^:]*\.rb):(\d*)/) do
           if ENV['TM_PROJECT_DIRECTORY']
             step_file = "<a href=\"txmt://open?url=file://#{File.expand_path($1)}&line=#{$2}\">#{$1}:#{$2}</a> "
           end
         end
-        
+
         @builder.div(:class => 'step_file') do |div|
           @builder.span do
             @builder << step_file
@@ -509,29 +479,29 @@ module Cucumber
       def inline_jquery
         File.read(File.dirname(__FILE__) + '/jquery-min.js')
       end
-      
+
       def inline_js_content
         <<-EOF
 
   SCENARIOS = "h3[id^='scenario_'],h3[id^=background_]";
-  
+
   $(document).ready(function() {
     $(SCENARIOS).css('cursor', 'pointer');
     $(SCENARIOS).click(function() {
       $(this).siblings().toggle(250);
     });
-    
+
     $("#collapser").css('cursor', 'pointer');
     $("#collapser").click(function() {
       $(SCENARIOS).siblings().hide();
     });
-    
+
     $("#expander").css('cursor', 'pointer');
     $("#expander").click(function() {
       $(SCENARIOS).siblings().show();
     });
   })
-  
+
   function moveProgressBar(percentDone) {
     $("cucumber-header").css('width', percentDone +"%");
   }
@@ -543,7 +513,7 @@ module Cucumber
     $('#'+element_id).css('background', '#FAF834');
     $('#'+element_id).css('color', '#000000');
   }
-  
+
         EOF
       end
 
@@ -580,12 +550,12 @@ module Cucumber
 
       def print_stat_string(features)
         string = String.new
-        string << dump_count(@step_mother.scenarios.length, "scenario")
-        scenario_count = print_status_counts{|status| @step_mother.scenarios(status)}
+        string << dump_count(@runtime.scenarios.length, "scenario")
+        scenario_count = print_status_counts{|status| @runtime.scenarios(status)}
         string << scenario_count if scenario_count
         string << "<br />"
-        string << dump_count(@step_mother.steps.length, "step")
-        step_count = print_status_counts{|status| @step_mother.steps(status)}
+        string << dump_count(@runtime.steps.length, "step")
+        step_count = print_status_counts{|status| @runtime.steps(status)}
         string << step_count if step_count
       end
 
