@@ -24,6 +24,10 @@ module Cucumber
           @pipe.send(method, *args, &blk)
         end
 
+        def respond_to?(method, include_private=false)
+          super || @pipe.respond_to?(method, include_private)
+        end
+
         def self.validate_pipe(pipe)
           unless [:stdout, :stderr].include? pipe
             raise ArgumentError, '#wrap only accepts :stderr or :stdout'
@@ -36,10 +40,10 @@ module Cucumber
           case pipe
           when :stdout
             wrapped = $stdout
-            $stdout = wrapped.unwrap!
+            $stdout = wrapped.unwrap! if $stdout.respond_to?(:unwrap!)
           when :stderr
             wrapped = $stderr
-            $stderr = wrapped.unwrap!
+            $stderr = wrapped.unwrap! if $stderr.respond_to?(:unwrap!)
           end
           wrapped
         end
