@@ -15,7 +15,7 @@ module Cucumber
         end
       end
 
-      def initialize(step_mother, io, options)
+      def initialize(runtime, io, options)
         @reportdir = ensure_dir(io, "junit")
         @options = options
       end
@@ -48,10 +48,10 @@ module Cucumber
           :name => @feature_name ) do
           @testsuite << @builder.target!
           @testsuite.tag!('system-out') do
-            @testsuite.cdata! @interceptedout.buffer.join
+            @testsuite.cdata! strip_control_chars(@interceptedout.buffer.join)
           end
           @testsuite.tag!('system-err') do
-            @testsuite.cdata! @interceptederr.buffer.join
+            @testsuite.cdata! strip_control_chars(@interceptederr.buffer.join)
           end
         end
 
@@ -130,21 +130,19 @@ module Cucumber
         @time += duration
         classname = @feature_name
         name = "#{@scenario}#{suffix}"
-        pending = [:pending, :undefined].include?(status)
-        passed = (status == :passed || (pending && !@options[:strict]))
+        pending = [:pending, :undefined].include?(status) && (!@options[:strict])
 
         @builder.testcase(:classname => classname, :name => name, :time => "%.6f" % duration) do
-          unless passed
+          if status == :skipped || pending
+            @builder.skipped
+            @skipped += 1
+          elsif status != :passed
             @builder.failure(:message => "#{status.to_s} #{name}", :type => status.to_s) do
               @builder.cdata! @output
               @builder.cdata!(format_exception(exception)) if exception
             end
             @failures += 1
           end
-          if passed and (status == :skipped || pending)
-            @builder.skipped
-            @skipped += 1
-          end
           @builder.tag!('system-out')
           @builder.tag!('system-err')
         end
@@ -166,6 +164,12 @@ module Cucumber
       def write_file(feature_filename, data)
         File.open(feature_filename, 'w') { |file| file.write(data) }
       end
+
+      # strip control chars from cdata, to make it safe for external parsers
+      def strip_control_chars(cdata)
+        cdata.scan(/[[:print:]\t\n\r]/).join
+      end
+      
     end
   end
 end
