@@ -18,16 +18,20 @@ module Cucumber
       include Io
       include Gherkin::Formatter::Escaping
       attr_writer :indent
-      attr_reader :step_mother
+      attr_reader :runtime
 
-      def initialize(step_mother, path_or_io, options)
-        @step_mother, @io, @options = step_mother, ensure_io(path_or_io, "pretty"), options
+      def initialize(runtime, path_or_io, options)
+        @runtime, @io, @options = runtime, ensure_io(path_or_io, "pretty"), options
         @exceptions = []
         @indent = 0
         @prefixes = options[:prefixes] || {}
         @delayed_messages = []
       end
 
+      def before_features(features)
+        print_profile_information
+      end
+
       def after_features(features)
         print_summary(features) unless @options[:autoformat]
       end
@@ -42,7 +46,7 @@ module Cucumber
           @io = ensure_file(file, "pretty")
         end
       end
-      
+
       def comment_line(comment_line)
         @io.puts(comment_line.indent(@indent))
         @io.flush
@@ -72,7 +76,7 @@ module Cucumber
         @indent = 2
         @scenario_indent = 2
       end
-      
+
       def after_feature_element(feature_element)
         @io.puts
         @io.flush
@@ -90,7 +94,7 @@ module Cucumber
         @io.flush
       end
 
-      def background_name(keyword, name, file_colon_line, source_indent)        
+      def background_name(keyword, name, file_colon_line, source_indent)
         print_feature_element_name(keyword, name, file_colon_line, source_indent)
       end
 
@@ -99,7 +103,7 @@ module Cucumber
         @io.puts
         @visiting_first_example_name = true
       end
-      
+
       def examples_name(keyword, name)
         @io.puts unless @visiting_first_example_name
         @visiting_first_example_name = false
@@ -110,7 +114,7 @@ module Cucumber
         @indent = 6
         @scenario_indent = 6
       end
-      
+
       def before_outline_table(outline_table)
         @table = outline_table
       end
@@ -119,7 +123,7 @@ module Cucumber
         @table = nil
         @indent = 4
       end
-      
+
       def scenario_name(keyword, name, file_colon_line, source_indent)
         print_feature_element_name(keyword, name, file_colon_line, source_indent)
       end
@@ -154,7 +158,7 @@ module Cucumber
       end
 
       def doc_string(string)
-        return if @hide_this_step
+        return if @options[:no_multiline] || @hide_this_step
         s = %{"""\n#{string}\n"""}.indent(@indent)
         s = s.split("\n").map{|l| l =~ /^\s+$/ ? '' : l}.join("\n")
         @io.puts(format_string(s, @current_step.status))
@@ -171,7 +175,7 @@ module Cucumber
         return if @options[:no_multiline] || @hide_this_step
         @table = multiline_arg
       end
-      
+
       def after_multiline_arg(multiline_arg)
         @table = nil
       end
@@ -208,7 +212,7 @@ module Cucumber
       end
 
       private
-      
+
       def print_feature_element_name(keyword, name, file_colon_line, source_indent)
         @io.puts if @scenario_indent == 6
         names = name.empty? ? [name] : name.split("\n")
@@ -220,7 +224,7 @@ module Cucumber
         end
         @io.puts
         names[1..-1].each {|s| @io.puts "    #{s}"}
-        @io.flush        
+        @io.flush
       end
 
       def cell_prefix(status)
