@@ -7,10 +7,14 @@ module Cucumber
     class Progress
       include Console
       include Io
-      attr_reader :step_mother
+      attr_reader :runtime
 
-      def initialize(step_mother, path_or_io, options)
-        @step_mother, @io, @options = step_mother, ensure_io(path_or_io, "progress"), options
+      def initialize(runtime, path_or_io, options)
+        @runtime, @io, @options = runtime, ensure_io(path_or_io, "progress"), options
+      end
+
+      def before_features(features)
+        print_profile_information
       end
 
       def after_features(features)
@@ -24,12 +28,12 @@ module Cucumber
       end
 
       def after_feature_element(*args)
-        progress(:failed) if @exception_raised
+        progress(:failed) if (defined? @exception_raised) and (@exception_raised)
         @exception_raised = false
       end
 
       def before_steps(*args)
-        progress(:failed) if @exception_raised
+        progress(:failed) if (defined? @exception_raised) and (@exception_raised)
         @exception_raised = false
       end
 
