@@ -10,13 +10,17 @@ module Cucumber
         attr_accessor :mean_duration, :status
       end
 
-      def initialize(step_mother, path_or_io, options)
-        @step_mother = step_mother
+      def initialize(runtime, path_or_io, options)
+        @runtime = runtime
         @io = ensure_io(path_or_io, "usage")
         @options = options
         @stepdef_to_match = Hash.new{|h,stepdef_key| h[stepdef_key] = []}
       end
 
+      def before_features(features)
+        print_profile_information
+      end
+
       def before_step(step)
         @step = step
         @start_time = Time.now
@@ -27,13 +31,14 @@ module Cucumber
       end
 
       def after_step_result(keyword, step_match, multiline_arg, status, exception, source_indent, background, file_colon_line)
-        if step_match.name.nil? # nil if it's from a scenario outline
-          stepdef_key = StepDefKey.new(step_match.step_definition.regexp_source, step_match.step_definition.file_colon_line)
+        step_definition = step_match.step_definition
+        unless step_definition.nil? # nil if it's from a scenario outline
+          stepdef_key = StepDefKey.new(step_definition.regexp_source, step_definition.file_colon_line)
 
           @stepdef_to_match[stepdef_key] << {
-            :keyword => keyword, 
-            :step_match => step_match, 
-            :status => status, 
+            :keyword => keyword,
+            :step_match => step_match,
+            :status => status,
             :file_colon_line => @step.file_colon_line,
             :duration => @duration
           }
@@ -117,11 +122,11 @@ module Cucumber
       end
 
       def add_unused_stepdefs
-        @step_mother.unmatched_step_definitions.each do |step_definition|
+        @runtime.unmatched_step_definitions.each do |step_definition|
           stepdef_key = StepDefKey.new(step_definition.regexp_source, step_definition.file_colon_line)
           @stepdef_to_match[stepdef_key] = []
         end
       end
     end
   end
-end
\ No newline at end of file
+end
