@@ -4,6 +4,19 @@ require 'cucumber/rb_support/rb_world'
 require 'cucumber/rb_support/rb_step_definition'
 require 'cucumber/rb_support/rb_hook'
 require 'cucumber/rb_support/rb_transform'
+require 'cucumber/rb_support/snippet'
+
+begin
+  require 'rspec/expectations'
+rescue LoadError
+  begin
+    require 'spec/expectations'
+    require 'spec/runner/differs/default'
+    require 'ostruct'
+  rescue LoadError
+    require 'test/unit/assertions'
+  end
+end
 
 module Cucumber
   module RbSupport
@@ -38,29 +51,25 @@ module Cucumber
         RbWorld.alias_adverb(adverb)
       end
 
-      def initialize(step_mother)
-        @step_mother = step_mother
+      def initialize(runtime)
+        @runtime = runtime
         @step_definitions = []
         RbDsl.rb_language = self
         @world_proc = @world_modules = nil
-        enable_rspec_expectations_if_available
+        @assertions_module = find_best_assertions_module
       end
 
-      def enable_rspec_expectations_if_available
+      def find_best_assertions_module
         begin
-          # RSpec >=2.0
-          require 'rspec/expectations'
-          @rspec_matchers = ::RSpec::Matchers
-        rescue LoadError => try_rspec_1_2_4_or_higher
+          ::RSpec::Matchers
+        rescue NameError
+          # RSpec >=1.2.4
           begin
-            require 'spec/expectations'
-            require 'spec/runner/differs/default'
-            require 'ostruct'
             options = OpenStruct.new(:diff_format => :unified, :context_lines => 3)
             Spec::Expectations.differ = Spec::Expectations::Differs::Default.new(options)
-            @rspec_matchers = ::Spec::Matchers
-          rescue LoadError => give_up
-            @rspec_matchers = Module.new{}
+            ::Spec::Matchers
+          rescue NameError
+            ::Test::Unit::Assertions
           end
         end
       end
@@ -75,25 +84,9 @@ module Cucumber
         end.compact
       end
 
-      ARGUMENT_PATTERNS = ['"(.*?)"', '(\d+)']
-
-      def snippet_text(code_keyword, step_name, multiline_arg_class)
-        snippet_pattern = Regexp.escape(step_name).gsub('\ ', ' ').gsub('/', '\/')
-        arg_count = 0
-        ARGUMENT_PATTERNS.each do |pattern|
-          snippet_pattern = snippet_pattern.gsub(Regexp.new(pattern), pattern)
-          arg_count += snippet_pattern.scan(pattern).length
-        end
-
-        block_args = (0...arg_count).map {|n| "arg#{n+1}"}
-        block_args << multiline_arg_class.default_arg_name unless multiline_arg_class.nil?
-        block_arg_string = block_args.empty? ? "" : " |#{block_args.join(", ")}|"
-        multiline_class_comment = ""
-        if(multiline_arg_class == Ast::Table)
-          multiline_class_comment = "# #{multiline_arg_class.default_arg_name} is a #{multiline_arg_class.to_s}\n  "
-        end
-
-        "#{code_keyword} /^#{snippet_pattern}$/ do#{block_arg_string}\n  #{multiline_class_comment}pending # express the regexp above with the code you wish you had\nend"
+      def snippet_text(code_keyword, step_name, multiline_arg_class, snippet_type = :regexp)
+        snippet_class = typed_snippet_class(snippet_type)
+        snippet_class.new(code_keyword, step_name, multiline_arg_class).to_s
       end
 
       def begin_rb_scenario(scenario)
@@ -128,13 +121,13 @@ module Cucumber
       def load_code_file(code_file)
         load File.expand_path(code_file) # This will cause self.add_step_definition, self.add_hook, and self.add_transform to be called from RbDsl
       end
-      
+
       protected
 
       def begin_scenario(scenario)
         begin_rb_scenario(scenario)
       end
-      
+
       def end_scenario
         @current_world = nil
       end
@@ -152,14 +145,14 @@ module Cucumber
 
       def extend_world
         @current_world.extend(RbWorld)
-        @current_world.extend(@rspec_matchers)
+        @current_world.extend(@assertions_module)
         (@world_modules || []).each do |mod|
           @current_world.extend(mod)
         end
       end
 
       def connect_world(scenario)
-        @current_world.__cucumber_step_mother = @step_mother
+        @current_world.__cucumber_runtime = @runtime
         @current_world.__natural_language = scenario.language
       end
 
@@ -176,6 +169,22 @@ module Cucumber
           o
         end
       end
+
+      SNIPPET_TYPES = {
+        :regexp => Snippet::Regexp,
+        :classic => Snippet::Classic,
+        :percent => Snippet::Percent
+      }
+
+      def typed_snippet_class(type)
+        SNIPPET_TYPES.fetch(type || :regexp)
+      end
+
+      def self.cli_snippet_type_options
+        SNIPPET_TYPES.keys.sort_by(&:to_s).map do |type|
+          SNIPPET_TYPES[type].cli_option_string(type)
+        end
+      end
     end
   end
 end
