@@ -1,7 +1,9 @@
 require 'fileutils'
+require 'multi_json'
 require 'gherkin/rubify'
 require 'gherkin/i18n'
 require 'cucumber/configuration'
+require 'cucumber/load_path'
 require 'cucumber/language_support/language_methods'
 require 'cucumber/formatter/duration'
 require 'cucumber/runtime/user_interface'
@@ -13,7 +15,7 @@ module Cucumber
   # This is the meaty part of Cucumber that ties everything together.
   class Runtime
     attr_reader :results
-    
+
     include Formatter::Duration
     include Runtime::UserInterface
 
@@ -24,28 +26,28 @@ module Cucumber
       @support_code = SupportCode.new(self, @configuration)
       @results = Results.new(@configuration)
     end
-    
+
     # Allows you to take an existing runtime and change it's configuration
     def configure(new_configuration)
       @configuration = Configuration.parse(new_configuration)
       @support_code.configure(@configuration)
       @results.configure(@configuration)
     end
-    
+
     def load_programming_language(language)
       @support_code.load_programming_language(language)
     end
-    
+
     def run!
       load_step_definitions
       fire_after_configuration_hook
 
       tree_walker = @configuration.build_tree_walker(self)
       self.visitor = tree_walker # Ugly circular dependency, but needed to support World#puts
-      
+
       tree_walker.visit_features(features)
     end
-    
+
     def features_paths
       @configuration.paths
     end
@@ -151,11 +153,17 @@ module Cucumber
           FileUtils.mkdir_p(@configuration.dotcucumber)
         end
         File.open(File.join(@configuration.dotcucumber, 'stepdefs.json'), 'w') do |io|
-          io.write(JSON.pretty_generate(stepdefs))
+          io.write(MultiJson.dump(stepdefs, :pretty => true))
         end
       end
     end
 
+    # Returns Ast::DocString for +string_without_triple_quotes+.
+    #
+    def doc_string(string_without_triple_quotes, content_type='', line_offset=0)
+      Ast::DocString.new(string_without_triple_quotes,content_type)
+    end
+
   private
 
     def fire_after_configuration_hook #:nodoc
@@ -164,8 +172,8 @@ module Cucumber
 
     def features
       @loader ||= Runtime::FeaturesLoader.new(
-        @configuration.feature_files, 
-        @configuration.filters, 
+        @configuration.feature_files,
+        @configuration.filters,
         @configuration.tag_expression)
       @loader.features
     end
@@ -180,4 +188,4 @@ module Cucumber
     end
   end
 
-end
\ No newline at end of file
+end
