@@ -5,9 +5,9 @@ require 'cucumber/runtime/for_programming_languages'
 module Cucumber
 
   class Runtime
-    
+
     class SupportCode
-      
+
       require 'forwardable'
       class StepInvoker
         include Gherkin::Rubify
@@ -20,15 +20,15 @@ module Cucumber
         end
 
         def step(step)
-          @support_code.invoke(step.name, Ast::MultilineArgument.from(step.doc_string || step.rows)) 
+          @support_code.invoke(step.name, Ast::MultilineArgument.from(step.doc_string || step.rows))
         end
 
         def eof
         end
       end
-    
+
       include Constantize
-      
+
       def initialize(user_interface, configuration={})
         @configuration = Configuration.parse(configuration)
         @runtime_facade = Runtime::ForProgrammingLanguages.new(self, user_interface)
@@ -36,11 +36,11 @@ module Cucumber
         @programming_languages = []
         @language_map = {}
       end
-      
+
       def configure(new_configuration)
         @configuration = Configuration.parse(new_configuration)
       end
-    
+
       # Invokes a series of steps +steps_text+. Example:
       #
       #   invoke(%Q{
@@ -49,13 +49,13 @@ module Cucumber
       #   })
       def invoke_steps(steps_text, i18n, file_colon_line)
         file, line = file_colon_line.split(':')
-        parser = Gherkin::Parser::Parser.new(StepInvoker.new(self), true, 'steps')
+        parser = Gherkin::Parser::Parser.new(StepInvoker.new(self), true, 'steps', false, i18n.iso_code)
         parser.parse(steps_text, file, line.to_i)
       end
 
       def invoke(step_name, multiline_argument=nil)
         multiline_argument = Cucumber::Ast::MultilineArgument.from(multiline_argument)
-        # It is very important to leave multiline_argument=nil as a vararg. Cuke4Duke needs it that way. 
+        # It is very important to leave multiline_argument=nil as a vararg. Cuke4Duke needs it that way.
         begin
           step_match(step_name).invoke(multiline_argument)
         rescue Exception => e
@@ -63,7 +63,7 @@ module Cucumber
           raise e
         end
       end
-      
+
       # Loads and registers programming language implementation.
       # Instances are cached, so calling with the same argument
       # twice will return the same instance.
@@ -76,7 +76,7 @@ module Cucumber
         @language_map[ext] = programming_language
         programming_language
       end
-    
+
       def load_files!(files)
         log.debug("Code:\n")
         files.each do |file|
@@ -84,14 +84,14 @@ module Cucumber
         end
         log.debug("\n")
       end
-      
+
       def load_files_from_paths(paths)
         files = paths.map { |path| Dir["#{path}/**/*"] }.flatten
         load_files! files
       end
-    
+
       def unmatched_step_definitions
-        @programming_languages.map do |programming_language| 
+        @programming_languages.map do |programming_language|
           programming_language.unmatched_step_definitions
         end.flatten
       end
@@ -99,20 +99,20 @@ module Cucumber
       def snippet_text(step_keyword, step_name, multiline_arg_class) #:nodoc:
         load_programming_language('rb') if unknown_programming_language?
         @programming_languages.map do |programming_language|
-          programming_language.snippet_text(step_keyword, step_name, multiline_arg_class)
+          programming_language.snippet_text(step_keyword, step_name, multiline_arg_class, @configuration.snippet_type)
         end.join("\n")
       end
-    
+
       def unknown_programming_language?
         @programming_languages.empty?
       end
-    
+
       def fire_hook(name, *args)
         @programming_languages.each do |programming_language|
           programming_language.send(name, *args)
         end
       end
-    
+
       def around(scenario, block)
         @programming_languages.reverse.inject(block) do |blk, programming_language|
           proc do
@@ -122,29 +122,38 @@ module Cucumber
           end
         end.call
       end
-      
+
       def step_definitions
         @programming_languages.map do |programming_language|
           programming_language.step_definitions
         end.flatten
       end
-    
+
       def step_match(step_name, name_to_report=nil) #:nodoc:
+        @match_cache ||= {}
+
+        match = @match_cache[[step_name, name_to_report]]
+        return match if match
+
+        @match_cache[[step_name, name_to_report]] = step_match_without_cache(step_name, name_to_report)
+      end
+
+      private
+
+      def step_match_without_cache(step_name, name_to_report=nil)
         matches = matches(step_name, name_to_report)
         raise Undefined.new(step_name) if matches.empty?
         matches = best_matches(step_name, matches) if matches.size > 1 && guess_step_matches?
         raise Ambiguous.new(step_name, matches, guess_step_matches?) if matches.size > 1
         matches[0]
       end
-    
-    private
-  
+
       def guess_step_matches?
         @configuration.guess?
       end
-    
+
       def matches(step_name, name_to_report)
-        @programming_languages.map do |programming_language| 
+        @programming_languages.map do |programming_language|
           programming_language.step_matches(step_name, name_to_report).to_a
         end.flatten
       end
@@ -164,7 +173,7 @@ module Cucumber
           top_groups
         end
       end
-    
+
       def load_file(file)
         if programming_language = programming_language_for(file)
           log.debug("  * #{file}\n")
@@ -173,11 +182,11 @@ module Cucumber
           log.debug("  * #{file} [NOT SUPPORTED]\n")
         end
       end
-    
+
       def log
         Cucumber.logger
       end
-    
+
       def programming_language_for(step_def_file)
         if ext = File.extname(step_def_file)[1..-1]
           return nil if @unsupported_programming_languages.index(ext)
@@ -192,7 +201,7 @@ module Cucumber
           nil
         end
       end
-    
+
     end
   end
-end
\ No newline at end of file
+end
