@@ -10,7 +10,7 @@ module Cucumber
           raise "I flunked"
         end
       end
-      
+
       def create_feature(dsl)
         dsl.Given /^a (.*) step with an inline arg:$/ do |what, table|
         end
@@ -26,14 +26,25 @@ module Cucumber
           %w{4444 55555 666666}
         ])
         doc_string = Ast::DocString.new(%{\n I like\nCucumber sandwich\n}, '')
-        
-        background = Ast::Background.new(Ast::Comment.new(""), 2, "Background:", "", "",
+        location = Ast::Location.new('foo.feature', 2)
+        language = double.as_null_object
+
+        background = Ast::Background.new(
+          language,
+          location,
+          Ast::Comment.new(""), 
+          "Background:", 
+          "", 
+          "",
           [
-            Step.new(3, "Given", "a passing step")
+            Step.new(language, location.on_line(3), "Given", "a passing step")
           ]
         )
-        
-        f = Ast::Feature.new(
+
+        location = Location.new('features/pretty_printing.feature', 0)
+
+        Ast::Feature.new(
+          location,
           background,
           Ast::Comment.new("# My feature comment\n"),
           Ast::Tags.new(6, [Gherkin::Formatter::Model::Tag.new('one', 6), Gherkin::Formatter::Model::Tag.new('two', 6)]),
@@ -41,22 +52,21 @@ module Cucumber
           "Pretty printing",
           "",
           [Ast::Scenario.new(
+            language,
+            location.on_line(9),
             background,
             Ast::Comment.new("    # My scenario comment  \n# On two lines \n"),
             Ast::Tags.new(8, [Gherkin::Formatter::Model::Tag.new('three', 8), Gherkin::Formatter::Model::Tag.new('four', 8)]),
-            9,
+            Ast::Tags.new(1, []),
             "Scenario:", "A Scenario", "",
             [
-              Step.new(10, "Given", "a passing step with an inline arg:", table),
-              Step.new(11, "Given", "a happy step with an inline arg:", doc_string),
-              Step.new(12, "Given", "a failing step")
+              Step.new(language, location.on_line(10), "Given", "a passing step with an inline arg:", table),
+              Step.new(language, location.on_line(11), "Given", "a happy step with an inline arg:", doc_string),
+              Step.new(language, location.on_line(12), "Given", "a failing step")
             ]
           )]
         )
-        f.file = 'features/pretty_printing.feature'
-        f.features = Features.new
-        f
       end
     end
   end
-end
\ No newline at end of file
+end
