@@ -6,16 +6,16 @@ module Cucumber::Ast
       describe "a header row" do
         before(:each) do
           @row = OutlineTable::ExampleRow.new(
-            mock('table', :index => 0), 
-            [mock('cell', :status= => nil)]
+            double('table', :index => 0),
+            [double('cell', :status= => nil)]
           )
         end
-        
+
         it "should raise an error if you try to call #failed?" do
-          @row.accept_plain mock('visitor', :visit_table_cell => nil)
+          @row.accept_plain double('visitor', :visit_table_cell => nil)
           lambda{ @row.failed? }.should raise_error(NoMethodError, /cannot pass or fail/)
         end
       end
     end
   end
-end
\ No newline at end of file
+end
