@@ -26,23 +26,28 @@ module Cucumber
           @eaten.should == n.to_i
         end
 
+        location = Ast::Location.new('foo.feature', 19)
+        language = double
+
         @scenario_outline = ScenarioOutline.new(
-          background=nil,
+          language,
+          location,
+          background=Ast::EmptyBackground.new,
           Comment.new(""),
           Tags.new(18, []),
-          19,
+          Tags.new(0, []),
           "Scenario:", "My outline", "",
           [
-            Step.new(20, 'Given', 'there are <start> cucumbers'),
-            Step.new(21, 'When',  'I eat <eat> cucumbers'),
-            Step.new(22, 'Then',  'I should have <left> cucumbers'),
-            Step.new(23, 'And',   'I should have <eat> cucumbers in my belly')
+            Step.new(language, location.on_line(20), 'Given', 'there are <start> cucumbers'),
+            Step.new(language, location.on_line(21), 'When',  'I eat <eat> cucumbers'),
+            Step.new(language, location.on_line(22), 'Then',  'I should have <left> cucumbers'),
+            Step.new(language, location.on_line(23), 'And',   'I should have <eat> cucumbers in my belly')
           ],
           [
             [
               [
+                location.on_line(24),
                 Comment.new("#Mmmm... cucumbers\n"),
-                24,
                 'Examples:',
                 'First table',
                 '',
@@ -61,6 +66,7 @@ module Cucumber
       it "should replace all variables and call outline once for each table row" do
         visitor = TreeWalker.new(@step_mother)
         visitor.should_receive(:visit_table_row).exactly(3).times
+        @scenario_outline.feature = double.as_null_object
         visitor.visit_feature_element(@scenario_outline)
       end
     end
