@@ -102,7 +102,7 @@ module Cucumber
             %w{4444 55555 666666}
           ])
         end
-          
+
         it "returns nil if headers do not match" do
           @table.match('does,not,match').should be_nil
         end
@@ -121,14 +121,14 @@ module Cucumber
             %w{two 22222}
           ])
         end
-                
-        it "should be convertible in to an array where each row is a hash" do 
+
+        it "should be convertible in to an array where each row is a hash" do
           @table.transpose.hashes[0].should == {'one' => '1111', 'two' => '22222'}
         end
       end
-      
+
       describe "#rows_hash" do
-                
+
         it "should return a hash of the rows" do
           table = Table.new([
             %w{one 1111},
@@ -158,7 +158,54 @@ module Cucumber
         end
       end
 
+      describe '#map_headers!' do
+        let(:table) do
+          Table.new([
+          %w{HELLO WORLD},
+          %w{4444 55555}
+          ])
+        end
+
+        it "renames the columns to the specified values in the provided hash" do
+          @table.map_headers!('one' => :three)
+          @table.hashes.first[:three].should == '4444'
+        end
+
+        it "allows renaming columns using regexp" do
+          @table.map_headers!(/one|uno/ => :three)
+          @table.hashes.first[:three].should == '4444'
+        end
+
+        it "copies column mappings" do
+          @table.map_column!('one') { |v| v.to_i }
+          @table.map_headers!('one' => 'three')
+          @table.hashes.first['three'].should == 4444
+        end
+
+        it "takes a block and operates on all the headers with it" do
+          table.map_headers! do |header|
+            header.downcase
+          end
+          table.hashes.first.keys.should =~ %w[hello world]
+        end
+
+        it "treats the mappings in the provided hash as overrides when used with a block" do
+          table.map_headers!('WORLD' => 'foo') do |header|
+            header.downcase
+          end
+
+          table.hashes.first.keys.should =~ %w[hello foo]
+        end
+      end
+
       describe '#map_headers' do
+        let(:table) do
+           Table.new([
+          %w{HELLO WORLD},
+          %w{4444 55555}
+          ])
+        end
+
         it "renames the columns to the specified values in the provided hash" do
           table2 = @table.map_headers('one' => :three)
           table2.hashes.first[:three].should == '4444'
@@ -176,31 +223,20 @@ module Cucumber
         end
 
         it "takes a block and operates on all the headers with it" do
-          table = Table.new([
-          ['HELLO', 'WORLD'],
-          %w{4444 55555}
-          ])
-
-          table.map_headers! do |header|
+          table2 = table.map_headers do |header|
             header.downcase
           end
 
-          table.hashes.first.keys.should =~ %w[hello world]
+          table2.hashes.first.keys.should =~ %w[hello world]
         end
 
         it "treats the mappings in the provided hash as overrides when used with a block" do
-          table = Table.new([
-          ['HELLO', 'WORLD'],
-          %w{4444 55555}
-          ])
-
-          table.map_headers!('WORLD' => 'foo') do |header|
+          table2 = table.map_headers('WORLD' => 'foo') do |header|
             header.downcase
           end
 
-          table.hashes.first.keys.should =~ %w[hello foo]
+          table2.hashes.first.keys.should =~ %w[hello foo]
         end
-
       end
 
       describe "replacing arguments" do
@@ -243,7 +279,7 @@ module Cucumber
                               %w{cat}
                             ])
           table_with_replaced_args = table.arguments_replaced({'<book>' => nil})
-          
+
           table_with_replaced_args.hashes[0]['book'].should == 'cat'
         end
 
@@ -258,13 +294,12 @@ module Cucumber
                               ['book', 'qty'],
                               ['<book>', nil],
                             ])
-          lambda{ 
+          lambda{
             table.arguments_replaced({'<book>' => nil, '<qty>' => '5'})
           }.should_not raise_error
         end
-
       end
-      
+
       describe "diff!" do
         it "should detect a complex diff" do
           t1 = table(%{
@@ -273,11 +308,11 @@ module Cucumber
             | 999999999 | 0000000000  | 01010101010 | 121212121212 |
             | 4000      | ABC         | DEF         | 50000        |
           }, __FILE__, __LINE__)
-          
+
           t2 = table(%{
-            | a     | 4444     | 1         | 
-            | bb    | 88888888 | 55555     | 
-            | ccc   | xxxxxxxx | 999999999 | 
+            | a     | 4444     | 1         |
+            | bb    | 88888888 | 55555     |
+            | ccc   | xxxxxxxx | 999999999 |
             | dddd  | 4000     | 300       |
             | e     | 50000    | 4000      |
           }, __FILE__, __LINE__)
@@ -346,7 +381,7 @@ module Cucumber
             ['name',  'male'],
             ['aslak', true]
           ])
-          t1.map_column!('male') { 
+          t1.map_column!('male') {
             'true'
           }
           t2 = Table.new([
@@ -405,7 +440,7 @@ module Cucumber
             t1.hashes
           end.should raise_error(%{2 headers matched /uk/: ["Cuke", "Duke"]})
         end
-        
+
         describe "raising" do
           before do
             @t = table(%{
@@ -414,7 +449,7 @@ module Cucumber
             }, __FILE__, __LINE__)
             @t.should_not == nil
           end
-          
+
           it "should raise on missing rows" do
             t = table(%{
               | a | b |
@@ -448,13 +483,7 @@ module Cucumber
             }, __FILE__, __LINE__)
             lambda { t1.dup.diff!(t2) }.should raise_error
 
-            begin
-              pending "http://groups.google.com/group/cukes/browse_thread/thread/5d96431c8245f05f" do
-                lambda { t1.dup.diff!(t2, :surplus_row => false) }.should_not raise_error
-              end
-            rescue => e
-              warn(e.message + " - see http://www.ruby-forum.com/topic/208508")
-            end
+            lambda { t1.dup.diff!(t2, :surplus_row => false) }.should_not raise_error
           end
 
           it "should raise on missing columns" do
@@ -494,22 +523,22 @@ module Cucumber
         it "should allow Array of Hash" do
           t1 = Table.new([{'name' => 'aslak', 'male' => 'true'}])
           t1.to_s(:indent => 12, :color => false).should == %{
-            |     name  |     male |
-            |     aslak |     true |
+            |     male |     name  |
+            |     true |     aslak |
           }
         end
       end
 
       it "should convert to sexp" do
-        @table.to_sexp.should == 
-          [:table, 
+        @table.to_sexp.should ==
+          [:table,
             [:row, -1,
-              [:cell, "one"], 
+              [:cell, "one"],
               [:cell, "four"],
               [:cell, "seven"]
             ],
             [:row, -1,
-              [:cell, "4444"], 
+              [:cell, "4444"],
               [:cell, "55555"],
               [:cell, "666666"]]]
       end
