@@ -7,14 +7,14 @@ module Cli
   describe Options do
 
     def given_cucumber_yml_defined_as(hash_or_string)
-      File.stub!(:exist?).and_return(true)
+      File.stub(:exist?).and_return(true)
       cucumber_yml = hash_or_string.is_a?(Hash) ? hash_or_string.to_yaml : hash_or_string
-      IO.stub!(:read).with('cucumber.yml').and_return(cucumber_yml)
+      IO.stub(:read).with('cucumber.yml').and_return(cucumber_yml)
     end
 
     before(:each) do
-      File.stub!(:exist?).and_return(false) # Meaning, no cucumber.yml exists
-      Kernel.stub!(:exit).and_return(nil)
+      File.stub(:exist?).and_return(false) # Meaning, no cucumber.yml exists
+      Kernel.stub(:exit).and_return(nil)
     end
 
     def output_stream
@@ -58,17 +58,13 @@ module Cli
           include RSpec::WorkInProgress
 
           it "lists all known langues" do
-            pending_under :java, "require gherkin >= b5e96f13" do
-              when_parsing '--i18n help' do
-                Kernel.should_receive(:exit)
-              end
+            when_parsing '--i18n help' do
+              Kernel.should_receive(:exit)
             end
           end
 
           it "exits the program" do
-            pending_under :java, "require gherkin >= b5e96f13" do
-              when_parsing('--i18n help') { Kernel.should_receive(:exit) }
-            end
+            when_parsing('--i18n help') { Kernel.should_receive(:exit) }
           end
         end
       end
@@ -127,25 +123,6 @@ module Cli
 
       context '-p PROFILE or --profile PROFILE' do
 
-        it "notifies the user that an individual profile is being used" do
-          given_cucumber_yml_defined_as({'foo' => [1,2,3]})
-          options.parse!(%w{--profile foo})
-          output_stream.string.should =~ /Using the foo profile...\n/
-        end
-
-        it "notifies the user when multiple profiles are being used" do
-          given_cucumber_yml_defined_as({'foo' => [1,2,3], 'bar' => ['v'], 'dog' => ['v']})
-          options.parse!(%w{--profile foo --profile bar --profile dog})
-          output_stream.string.should =~ /Using the foo, bar and dog profiles...\n/
-        end
-
-        it "notifies the user of all profiles being used, even when they are nested" do
-          given_cucumber_yml_defined_as('foo' => '-p bar', 'bar' => 'features')
-          after_parsing('-p foo') do
-            output_stream.string.should =~ /Using the foo and bar profiles.../
-          end
-        end
-
         it "uses the default profile passed in during initialization if none are specified by the user" do
           given_cucumber_yml_defined_as({'default' => '--require some_file'})
 
@@ -227,6 +204,25 @@ module Cli
           options[:formats].should == [['progress', output_stream], ['html', 'features.html']]
         end
 
+        it "only reads cucumber.yml once" do
+          original_parse_count = $cucumber_yml_read_count
+          $cucumber_yml_read_count = 0
+
+          begin
+            given_cucumber_yml_defined_as(<<-END
+            <% $cucumber_yml_read_count += 1 %>
+            default: --format pretty
+            END
+            )
+            options = Options.new(output_stream, error_stream, :default_profile => 'default')
+            options.parse!(%w(-f progress))
+
+            $cucumber_yml_read_count.should == 1
+          ensure
+            $cucumber_yml_read_count = original_parse_count
+          end
+        end
+
         it "respects --quiet when defined in the profile" do
           given_cucumber_yml_defined_as('foo' => '-q')
           options.parse!(%w[-p foo])
@@ -293,6 +289,15 @@ module Cli
           options[:paths].should == ['my_feature.feature']
         end
       end
+
+      context '--snippet-type' do
+        it "parses the snippet type argument" do
+          after_parsing('--snippet-type classic') do
+            options[:snippet_type].should eql :classic
+          end
+        end
+      end
+
     end
 
     describe '#expanded_args_without_drb' do
@@ -338,20 +343,20 @@ module Cli
 
     end
 
-    describe "dry-run" do 
+    describe "dry-run" do
       it "should have the default value for snippets" do
         given_cucumber_yml_defined_as({'foo' => %w[--dry-run]})
         options.parse!(%w{--dry-run})
         options[:snippets].should == true
       end
 
-      it "should set snippets to false when no-snippets provided after dry-run" do 
+      it "should set snippets to false when no-snippets provided after dry-run" do
         given_cucumber_yml_defined_as({'foo' => %w[--dry-run --no-snippets]})
         options.parse!(%w{--dry-run --no-snippets})
         options[:snippets].should == false
       end
 
-      it "should set snippets to false when no-snippets provided before dry-run" do 
+      it "should set snippets to false when no-snippets provided before dry-run" do
         given_cucumber_yml_defined_as({'foo' => %w[--no-snippet --dry-run]})
         options.parse!(%w{--no-snippets --dry-run})
         options[:snippets].should == false
