@@ -17,23 +17,23 @@ module Cucumber
           nodes.detect{ |node| node.text =~ regexp }
         end
       end
-    
+
       before(:each) do
         @out = StringIO.new
         @formatter = Html.new(step_mother, @out, {})
         step_mother.visitor = @formatter
       end
-    
+
       it "should not raise an error when visiting a blank feature name" do
         lambda { @formatter.feature_name("Feature", "") }.should_not raise_error
       end
-      
+
       describe "given a single feature" do
         before(:each) do
           run_defined_feature
           @doc = Nokogiri.HTML(@out.string)
         end
-        
+
         describe "basic feature" do
           define_feature <<-FEATURE
             Feature: Bananas
@@ -41,23 +41,23 @@ module Cucumber
               As a human
               I must eat bananas
           FEATURE
-                
+
           it "should output a main container div" do
             @out.string.should =~ /\<div class="cucumber"\>/
           end
         end
-        
+
         describe "with a comment" do
           define_feature <<-FEATURE
             # Healthy
             Feature: Foo
           FEATURE
-        
+
           it { @out.string.should =~ /^\<!DOCTYPE/ }
           it { @out.string.should =~ /\<\/html\>$/ }
           it { @doc.should have_css_node('.feature .comment', /Healthy/) }
         end
-      
+
         describe "with a tag" do
           define_feature <<-FEATURE
             @foo
@@ -66,7 +66,7 @@ module Cucumber
 
           it { @doc.should have_css_node('.feature .tag', /foo/) }
         end
-      
+
         describe "with a narrative" do
           define_feature <<-FEATURE
             Feature: Bananas
@@ -78,18 +78,18 @@ module Cucumber
           it { @doc.should have_css_node('.feature h2', /Bananas/) }
           it { @doc.should have_css_node('.feature .narrative', /must eat bananas/) }
         end
-      
+
         describe "with a background" do
           define_feature <<-FEATURE
             Feature: Bananas
-          
+
             Background:
               Given there are bananas
           FEATURE
 
           it { @doc.should have_css_node('.feature .background', /there are bananas/) }
         end
-      
+
         describe "with a scenario" do
           define_feature <<-FEATURE
           Feature: Banana party
@@ -101,14 +101,14 @@ module Cucumber
           it { @doc.should have_css_node('.feature h3', /Monkey eats banana/) }
           it { @doc.should have_css_node('.feature .scenario .step', /there are bananas/) }
         end
-      
+
         describe "with a scenario outline" do
           define_feature <<-FEATURE
           Feature: Fud Pyramid
 
             Scenario Outline: Monkey eats a balanced diet
               Given there are <Things>
-          
+
               Examples: Fruit
                | Things  |
                | apples  |
@@ -118,14 +118,14 @@ module Cucumber
                | broccoli |
                | carrots  |
           FEATURE
-        
+
           it { @doc.should have_css_node('.feature .scenario.outline h4', /Fruit/) }
           it { @doc.should have_css_node('.feature .scenario.outline h4', /Vegetables/) }
           it { @doc.css('.feature .scenario.outline h4').length.should == 2}
           it { @doc.should have_css_node('.feature .scenario.outline table', //) }
           it { @doc.should have_css_node('.feature .scenario.outline table td', /carrots/) }
         end
-      
+
         describe "with a step with a py string" do
           define_feature <<-FEATURE
           Feature: Traveling circus
@@ -136,11 +136,14 @@ module Cucumber
                foo
                """
           FEATURE
-        
+
           it { @doc.should have_css_node('.feature .scenario .val', /foo/) }
         end
 
         describe "with a multiline step arg" do
+          define_steps do
+            Given(/there are monkeys:/) { |table| }
+          end
           define_feature <<-FEATURE
           Feature: Traveling circus
 
@@ -150,10 +153,11 @@ module Cucumber
                | foo  |
                | bar  |
           FEATURE
-        
+
           it { @doc.should have_css_node('.feature .scenario table td', /foo/) }
+          it { @out.string.include?('makeYellow(\'scenario_1\')').should be_false }
         end
-      
+
         describe "with a table in the background and the scenario" do
           define_feature <<-FEATURE
           Feature: accountant monkey
@@ -167,10 +171,10 @@ module Cucumber
                | e | f |
                | g | h |
           FEATURE
-        
+
           it { @doc.css('td').length.should == 8 }
         end
-      
+
         describe "with a py string in the background and the scenario" do
           define_feature <<-FEATURE
           Feature: py strings
@@ -190,12 +194,12 @@ module Cucumber
           it { @doc.css('.feature .background pre.val').length.should == 1 }
           it { @doc.css('.feature .scenario pre.val').length.should == 1 }
         end
-      
+
         describe "with a step that fails in the scenario" do
           define_steps do
             Given(/boo/) { raise StandardError, 'eek'.freeze }
           end
-        
+
           define_feature(<<-FEATURE)
           Feature: Animal Cruelty
 
@@ -206,12 +210,12 @@ module Cucumber
           it { @doc.should have_css_node('.feature .scenario .step.failed .message', /eek/) }
           it { @doc.should have_css_node('.feature .scenario .step.failed .message', /StandardError/) }
         end
-      
-        describe "with a step that fails in the backgound" do
+
+        describe "with a step that fails in the background" do
           define_steps do
             Given(/boo/) { raise 'eek' }
           end
-        
+
           define_feature(<<-FEATURE)
           Feature: shouting
             Background:
@@ -219,10 +223,14 @@ module Cucumber
             Scenario:
               Given yay
             FEATURE
-        
+
           it { @doc.should have_css_node('.feature .background .step.failed', /eek/) }
+          it { @out.string.should_not include('makeRed(\'scenario_0\')') }
+          it { @out.string.should include('makeRed(\'background_0\')') }
           it { @doc.should_not have_css_node('.feature .scenario .step.failed', //) }
           it { @doc.should have_css_node('.feature .scenario .step.undefined', /yay/) }
+          it { @doc.should have_css_node('.feature .background .backtrace', //) }
+          it { @doc.should_not have_css_node('.feature .scenario .backtrace', //) }
         end
 
         describe "with a step that embeds a snapshot" do
@@ -231,25 +239,25 @@ module Cucumber
           end
 
           define_feature(<<-FEATURE)
-          Feature: 
+          Feature:
             Scenario:
               Given snap
             FEATURE
 
           it { @doc.css('.embed img').first.attributes['src'].to_s.should == "snapshot.jpeg" }
         end
-        
+
         describe "with an undefined Given step then an undefined And step" do
           define_feature(<<-FEATURE)
-          Feature: 
+          Feature:
             Scenario:
               Given some undefined step
               And another undefined step
             FEATURE
-            
+
           it { @doc.css('pre').map { |pre| /^(Given|And)/.match(pre.text)[1] }.should == ["Given", "Given"] }
         end
-      
+
       end
     end
   end
