@@ -19,10 +19,43 @@ module Cucumber::Formatter
     end
 
     before(:each) do
-      File.stub!(:directory?).and_return(true)
+      File.stub(:directory?).and_return(true)
       @formatter = TestDoubleJunitFormatter.new(step_mother, '', {})
     end
 
+    describe "should be able to strip control chars from cdata" do
+      before(:each) do
+        run_defined_feature
+        @doc = Nokogiri.XML(@formatter.written_files.values.first)
+      end
+      define_feature "
+          Feature: One passing scenario, one failing scenario
+
+            Scenario: Passing
+              Given a passing ctrl scenario
+        "
+      class Junit
+        def before_step(step)
+          if step.name.match("a passing ctrl scenario")
+            Interceptor::Pipe.unwrap! :stdout
+            @fake_io = $stdout = StringIO.new
+            $stdout.sync = true
+            @interceptedout = Interceptor::Pipe.wrap(:stdout)
+          end
+        end
+
+        def after_step(step)
+          if step.name.match("a passing ctrl scenario")
+            @interceptedout.write("boo\b\cx\e\a\f boo ")
+            $stdout = STDOUT
+            @fake_io.close
+          end
+        end
+      end
+      
+      it { @doc.xpath('//testsuite/system-out').first.content.should match(/\s+boo boo\s+/) }
+    end
+
     describe "a feature with no name" do
       define_feature <<-FEATURE
         Feature:
@@ -113,6 +146,22 @@ module Cucumber::Formatter
         it { @doc.to_s.should_not =~ /type="skipped"/}
       end
 
+      describe "scenario with skipped test in junit report" do
+        define_feature <<-FEATURE
+          Feature: junit report with skipped test
+
+            Scenario Outline: skip a test and junit report of the same
+              Given a <skip> scenario
+
+            Examples:
+              | skip   |
+              | undefined |
+              | undefined  |
+        FEATURE
+
+        it { @doc.to_s.should =~ /skipped="2"/}
+      end
+
       describe "with a regular data table scenario" do
         define_steps do
           Given(/the following items on a shortlist/) { |table| }
