@@ -8,14 +8,14 @@ module Cucumber
       before(:each) do
         Cucumber::Term::ANSIColor.coloring = false
         @out = StringIO.new
-        progress = Cucumber::Formatter::Progress.new(mock("step mother"), @out, {})
+        progress = Cucumber::Formatter::Progress.new(double("step mother"), @out, {})
         @visitor = Cucumber::Ast::TreeWalker.new(nil, [progress])
       end
- 
+
       describe "visiting a table cell value without a status" do
         it "should take the status from the last run step" do
           @visitor.visit_step_result('', '', nil, :failed, nil, 10, nil, nil)
-          outline_table = mock()
+          outline_table = double()
           outline_table.should_receive(:accept) do |visitor|
             visitor.visit_table_cell_value('value', nil)
           end
