@@ -10,92 +10,71 @@ module Cucumber
       let(:support_code) do
         Cucumber::Runtime::SupportCode.new(user_interface, {})
       end
-      let(:dsl) do 
+      let(:dsl) do
         rb
         Object.new.extend(RbSupport::RbDsl)
       end
 
-      def unindented(s)
-        s.split("\n")[1..-2].join("\n").indent(-10)
-      end
-      
       describe "snippets" do
-    
-        it "should recognise numbers in name and make according regexp" do
-          rb.snippet_text('Given', 'Cloud 9 yeah', nil).should == unindented(%{
-          Given /^Cloud (\\d+) yeah$/ do |arg1|
-            pending # express the regexp above with the code you wish you had
-          end
-          })
+        let(:snippet) { double.as_null_object }
+
+        it "creates a regexp Snippet class by default" do
+          Snippet::Regexp.should_receive(:new).and_return(snippet)
+          rb.snippet_text('Given', 'A "string" with 4 spaces', nil)
         end
 
-        it "should recognise a mix of ints, strings and why not a table too" do
-          rb.snippet_text('Given', 'I have 9 "awesome" cukes in 37 "boxes"', Cucumber::Ast::Table).should == unindented(%{
-          Given /^I have (\\d+) "(.*?)" cukes in (\\d+) "(.*?)"$/ do |arg1, arg2, arg3, arg4, table|
-            # table is a Cucumber::Ast::Table
-            pending # express the regexp above with the code you wish you had
-          end
-          })
+        it "creates a regexp Snippet class explicitly" do
+          Snippet::Regexp.should_receive(:new).and_return(snippet)
+          rb.snippet_text('Given', 'A "string" with 4 spaces', nil, :regexp)
         end
 
-        it "should recognise quotes in name and make according regexp" do
-          rb.snippet_text('Given', 'A "first" arg', nil).should == unindented(%{
-          Given /^A "(.*?)" arg$/ do |arg1|
-            pending # express the regexp above with the code you wish you had
-          end
-          })
+        it "creates a classic Snippet class" do
+          Snippet::Classic.should_receive(:new).and_return(snippet)
+          rb.snippet_text('Given', 'A "string" with 4 spaces', nil, :classic)
         end
 
-        it "should recognise several quoted words in name and make according regexp and args" do
-          rb.snippet_text('Given', 'A "first" and "second" arg', nil).should == unindented(%{
-          Given /^A "(.*?)" and "(.*?)" arg$/ do |arg1, arg2|
-            pending # express the regexp above with the code you wish you had
-          end
-          })
-        end
-      
-        it "should not use quote group when there are no quotes" do
-          rb.snippet_text('Given', 'A first arg', nil).should == unindented(%{
-          Given /^A first arg$/ do
-            pending # express the regexp above with the code you wish you had
-          end
-          })
+        it "creates a percent Snippet class" do
+          Snippet::Percent.should_receive(:new).and_return(snippet)
+          rb.snippet_text('Given', 'A "string" with 4 spaces', nil, :percent)
         end
 
-        it "should be helpful with tables" do
-          rb.snippet_text('Given', 'A "first" arg', Cucumber::Ast::Table).should == unindented(%{
-          Given /^A "(.*?)" arg$/ do |arg1, table|
-            # table is a Cucumber::Ast::Table
-            pending # express the regexp above with the code you wish you had
-          end
-          })
+        it "passes all parameters to Snippet contructor" do
+          code_keyword, pattern, multiline_argument_class = double, double, double
+          Snippet::Regexp.should_receive(:new).with(code_keyword, pattern, multiline_argument_class)
+          rb.snippet_text(code_keyword, pattern, multiline_argument_class)
         end
-      
+
+        it "renders the snippet" do
+          Snippet::Regexp.stub(:new => snippet)
+          snippet.should_receive(:to_s)
+          rb.snippet_text('Given', 'A "string" with 4 spaces', nil)
+        end
+
       end
-    
+
       describe "#load_code_file" do
         after do
           FileUtils.rm_rf('tmp.rb')
         end
-        
+
         def a_file_called(name)
           File.open('tmp.rb', 'w') do |f|
             f.puts yield
           end
         end
-        
+
         it "re-loads the file when called multiple times" do
           a_file_called('tmp.rb') do
             "$foo = 1"
           end
-          
+
           rb.load_code_file('tmp.rb')
           $foo.should == 1
-          
+
           a_file_called('tmp.rb') do
             "$foo = 2"
           end
-          
+
           rb.load_code_file('tmp.rb')
           $foo.should == 2
         end
@@ -127,7 +106,7 @@ module Cucumber
 
         it "should implicitly extend world with modules" do
           dsl.World(ModuleOne, ModuleTwo)
-          rb.before(mock('scenario').as_null_object)
+          rb.before(double('scenario').as_null_object)
           class << rb.current_world
             included_modules.inspect.should =~ /ModuleOne/ # Workaround for RSpec/Ruby 1.9 issue with namespaces
             included_modules.inspect.should =~ /ModuleTwo/
@@ -189,6 +168,15 @@ or http://wiki.github.com/cucumber/cucumber/a-whole-new-world.
             rb.execute_transforms(['abc']).should == [42]
             rb.execute_transforms(['abbc']).should == [42]
           end
+
+          it "transforms times" do
+            require 'time'
+            dsl.Transform(/^(\d\d-\d\d-\d\d\d\d)$/) do |arg|
+              Time.parse(arg)
+            end
+            rb.execute_transforms(['10-0E-1971']).should == ['10-0E-1971']
+            rb.execute_transforms(['10-03-1971']).should == [Time.parse('10-03-1971')]
+          end
         end
 
         describe "with capture groups" do
@@ -255,7 +243,7 @@ or http://wiki.github.com/cucumber/cucumber/a-whole-new-world.
           fish = dsl.Before('@fish'){}
           meat = dsl.Before('@meat'){}
 
-          scenario = mock('Scenario')
+          scenario = double('Scenario')
           scenario.should_receive(:accept_hook?).with(fish).and_return(true)
           scenario.should_receive(:accept_hook?).with(meat).and_return(false)
 
@@ -269,7 +257,7 @@ or http://wiki.github.com/cucumber/cucumber/a-whole-new-world.
           b = dsl.Around('@tag') do |scenario, block|
           end
 
-          scenario = mock('Scenario')
+          scenario = double('Scenario')
           scenario.should_receive(:accept_hook?).with(a).and_return(true)
           scenario.should_receive(:accept_hook?).with(b).and_return(false)
 
