@@ -6,13 +6,13 @@ module Cucumber
   module WireSupport
     describe Configuration do
       let(:wire_file) { Tempfile.new('wire') }
-      let(:config) { Configuration.new(wire_file.path) }
-      
+      let(:config) { Configuration.from_file(wire_file.path) }
+
       def write_wire_file(contents)
         wire_file << contents
         wire_file.close
       end
-      
+
       it "reads the hostname / port from the file" do
         write_wire_file %q{
           host: localhost
@@ -21,7 +21,7 @@ module Cucumber
         config.host.should == 'localhost'
         config.port.should == 54321
       end
-      
+
       it "reads the timeout for a specific message" do
         write_wire_file %q{
           host: localhost
@@ -31,7 +31,17 @@ module Cucumber
         }
         config.timeout('invoke').should == 99
       end
-      
+
+      it "reads the timeout for a connect message" do
+        write_wire_file %q{
+          host: localhost
+          port: 54321
+          timeout:
+            connect: 99
+        }
+        config.timeout('connect').should == 99
+      end
+
       describe "a wire file with no timeouts specified" do
         before(:each) do
           write_wire_file %q{
@@ -39,7 +49,7 @@ module Cucumber
             port: 54321
           }
         end
-        
+
         %w(invoke begin_scenario end_scenario).each do |message|
           it "sets the default timeout for '#{message}' to 120 seconds" do
             config.timeout(message).should == 120
@@ -48,4 +58,4 @@ module Cucumber
       end
     end
   end
-end
\ No newline at end of file
+end
