@@ -5,10 +5,10 @@ module Cucumber
   module WireSupport
     describe WireException do
       before(:each) do
-        @host, @port = 'localhost', '54321'
+        @config = Configuration.new('host' => 'localhost', 'port' => 54321)
       end
       def exception
-        WireException.new(@data, @host, @port)
+        WireException.new(@data, @config)
       end
       describe "with just a message" do
         before(:each) do
@@ -18,7 +18,7 @@ module Cucumber
           exception.to_s.should == "foo"
         end
       end
-      
+
       describe "with a message and an exception" do
         before(:each) do
           @data = {'message' => 'foo', 'exception' => 'Bar'}
@@ -30,7 +30,7 @@ module Cucumber
           exception.class.to_s.should == 'Bar from localhost:54321'
         end
       end
-      
+
       describe "with a custom backtrace" do
         before(:each) do
           @data = {'message' => 'foo', 'backtrace' => ['foo', 'bar', 'baz']}
@@ -41,4 +41,4 @@ module Cucumber
       end
     end
   end
-end
\ No newline at end of file
+end
