@@ -5,14 +5,14 @@ module Cucumber
   module WireSupport
     describe WireLanguage do
       def stub_wire_file!(filename, config)
-        Configuration.stub!(:new).with(filename).and_return config
+        Configuration.stub(:from_file).with(filename).and_return config
       end
-      
+
       describe "#load_code_file" do
         before(:each) do
           stub_wire_file! 'foo.wire', :config
         end
-      
+
         it "creates a RemoteSteps object" do
           Connection.should_receive(:new).with(:config)
           WireLanguage.new(nil).load_code_file('foo.wire')
@@ -23,9 +23,9 @@ module Cucumber
         def stub_remote_steps!(config, attributes)
           Connection.should_receive(:new).
             with(config).
-            and_return( mock('remote_steps', attributes) )
+            and_return( double('remote_steps', attributes) )
         end
-        
+
         before(:each) do
           stub_wire_file! 'one.wire', :config_one
           stub_wire_file! 'two.wire', :config_two
