@@ -6,7 +6,7 @@ module Cucumber
     describe WireStepDefinition, "#invoke" do
       describe "if one of the arguments is a table" do
         it "should pass the raw table to the connection" do
-          connection = mock('connection')
+          connection = double('connection')
           step_definition = WireStepDefinition.new(connection, 'id' => 'the-id')
           expected_args = ["a","b", [["1","2"],["3","4"]]]
           connection.should_receive(:invoke).with('the-id', expected_args)
@@ -17,4 +17,4 @@ module Cucumber
       end
     end
   end
-end
\ No newline at end of file
+end
