@@ -13,7 +13,7 @@ require 'bundler'
 Bundler.setup
 
 require 'cucumber'
-$KCODE='u' unless Cucumber::RUBY_1_9
+$KCODE='u' if Cucumber::RUBY_1_8_7
 
 RSpec.configure do |c|
   c.before do
@@ -25,7 +25,7 @@ module RSpec
   module WorkInProgress
     def pending_under platforms, reason, &block
       if [platforms].flatten.map(&:to_s).include? RUBY_PLATFORM
-        pending "pending under #{platforms.inspect} because: #{reason}", &block 
+        pending "pending under #{platforms.inspect} because: #{reason}", &block
       else
         yield
       end
